0.9.9 API documentation: matrix_float3x4.hpp Source File

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

matrix_float3x4.hpp
Go to the documentation of this file.
1
4 #pragma once
5 #include "../detail/type_mat3x4.hpp"
6
7 namespace glm
8 {
11
15 typedef mat<3, 4, float, defaultp> mat3x4;
16
18 }//namespace glm
glm::mat3x4
mat< 3, 4, float, defaultp > mat3x4
3 columns of 4 components matrix of single-precision floating-point numbers.
Definition: matrix_float3x4.hpp:15
glm
Definition: common.hpp:20